/****************************************************************************
** ui.h extension file, included from the uic-generated form implementation.
**
** If you wish to add, delete or rename functions or slots use
** Qt Designer which will update this file, preserving your code. Create an
** init() function in place of a constructor, and a destroy() function in
** place of a destructor.
*****************************************************************************/


void DialogGeometry::initMe(QRect rect)
{
	m_pEditX->setText (QString ("%1").arg(rect.x()));
	m_pEditY->setText (QString ("%1").arg(rect.y()));
	m_pEditWidth ->setText (QString ("%1").arg(rect.width()));
	m_pEditHeight->setText (QString ("%1").arg(rect.height()));
	
	m_rectGeometry = rect;
}

void DialogGeometry::slotWidth()
{
	if (m_pCheckAspect->isChecked())	{
		float fAspect = (float)m_rectGeometry.height() / (float)m_rectGeometry.width();
		int iWidth = m_pEditWidth->text().toInt();
		m_pEditHeight->setText (QString ("%1").arg((int)(fAspect * iWidth)));
	}
}

void DialogGeometry::slotHeight()
{
	if (m_pCheckAspect->isChecked())	{
		float fAspect = (float)m_rectGeometry.width() / (float)m_rectGeometry.height();
		int iHeight = m_pEditHeight->text().toInt();
		m_pEditWidth->setText (QString ("%1").arg((int)(fAspect * iHeight)));
	}
}
